@@ -121,6 +121,7 @@ class DataLinspace(Data):
         include_endpoint=True,
         is_components=False,
         symmetries=-1,
+        is_overlay=False,
         symbol="",
         name="",
         unit="",
@@ -157,6 +158,8 @@ class DataLinspace(Data):
                 is_components = init_dict["is_components"]
             if "symmetries" in list(init_dict.keys()):
                 symmetries = init_dict["symmetries"]
+            if "is_overlay" in list(init_dict.keys()):
+                is_overlay = init_dict["is_overlay"]
             if "symbol" in list(init_dict.keys()):
                 symbol = init_dict["symbol"]
             if "name" in list(init_dict.keys()):
@@ -173,6 +176,7 @@ class DataLinspace(Data):
         self.include_endpoint = include_endpoint
         self.is_components = is_components
         self.symmetries = symmetries
+        self.is_overlay = is_overlay
         # Call Data init
         super(DataLinspace, self).__init__(
             symbol=symbol, name=name, unit=unit, normalizations=normalizations
@@ -193,6 +197,7 @@ class DataLinspace(Data):
         DataLinspace_str += "include_endpoint = " + str(self.include_endpoint) + linesep
         DataLinspace_str += "is_components = " + str(self.is_components) + linesep
         DataLinspace_str += "symmetries = " + str(self.symmetries) + linesep
+        DataLinspace_str += "is_overlay = " + str(self.is_overlay) + linesep
         return DataLinspace_str
 
     def __eq__(self, other):
@@ -218,6 +223,8 @@ class DataLinspace(Data):
             return False
         if other.symmetries != self.symmetries:
             return False
+        if other.is_overlay != self.is_overlay:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -245,6 +252,8 @@ class DataLinspace(Data):
             diff_list.append(name + ".is_components")
         if other._symmetries != self._symmetries:
             diff_list.append(name + ".symmetries")
+        if other._is_overlay != self._is_overlay:
+            diff_list.append(name + ".is_overlay")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -265,6 +274,7 @@ class DataLinspace(Data):
         if self.symmetries is not None:
             for key, value in self.symmetries.items():
                 S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.is_overlay)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -293,6 +303,7 @@ class DataLinspace(Data):
         DataLinspace_dict["symmetries"] = (
             self.symmetries.copy() if self.symmetries is not None else None
         )
+        DataLinspace_dict["is_overlay"] = self.is_overlay
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         DataLinspace_dict["__class__"] = "DataLinspace"
@@ -308,6 +319,7 @@ class DataLinspace(Data):
         self.include_endpoint = None
         self.is_components = None
         self.symmetries = None
+        self.is_overlay = None
         # Set to None the properties inherited from Data
         super(DataLinspace, self)._set_None()
 
@@ -395,7 +407,7 @@ class DataLinspace(Data):
     include_endpoint = property(
         fget=_get_include_endpoint,
         fset=_set_include_endpoint,
-        doc=u"""Boolean indicating if the endpoint must be included
+        doc=u"""True if the endpoint must be included
 
         :Type: bool
         """,
@@ -413,7 +425,7 @@ class DataLinspace(Data):
     is_components = property(
         fget=_get_is_components,
         fset=_set_is_components,
-        doc=u"""Boolean indicating if the axis values are strings: True if strings
+        doc=u"""True if the axis values are strings
 
         :Type: bool
         """,
@@ -438,3 +450,21 @@ class DataLinspace(Data):
         :Type: dict
         """,
     )
+
+    def _get_is_overlay(self):
+        """getter of is_overlay"""
+        return self._is_overlay
+
+    def _set_is_overlay(self, value):
+        """setter of is_overlay"""
+        check_var("is_overlay", value, "bool")
+        self._is_overlay = value
+
+    is_overlay = property(
+        fget=_get_is_overlay,
+        fset=_set_is_overlay,
+        doc=u"""True if axis must be used to overlay curves in plots
+
+        :Type: bool
+        """,
+    )
